import { DefaultTheme, css, CSSObject, StyledProps } from 'styled-components';
export declare type BreakpointNameConstraint = string | number | symbol;
export declare type BreakpointMap<B extends BreakpointNameConstraint> = {
    [breakpoint in B]: number;
};
declare type ThemeShape<B extends BreakpointNameConstraint> = {
    breakpoints: BreakpointMap<B>;
};
export declare type DefaultBreakpointName = 'mobile' | 'tablet' | 'desktop';
export declare type ThemedBreakpointName = DefaultTheme extends ThemeShape<infer B> ? B : DefaultBreakpointName;
export declare type BreakpointFunction<B extends BreakpointNameConstraint> = (breakpointA: B, breakpointB?: B) => typeof css;
export declare type ThemedBreakpointFunction<B extends BreakpointNameConstraint> = (breakpointA: B, breakpointB?: B) => <P extends object>({ theme }: StyledProps<P>) => typeof css;
export declare type ValueConstraint = string | number;
export declare type ValueOrValueMap<B extends BreakpointNameConstraint, V extends ValueConstraint> = V | {
    [breakpoint in B]?: V;
};
export declare type ValueToStyleFunction<V extends ValueConstraint> = (value: V) => string | CSSObject | ReturnType<typeof css>;
export declare type MapFunction<B extends BreakpointNameConstraint, V extends ValueConstraint> = (valueOrValues: ValueOrValueMap<B, V>, mapValueToStyle: ValueToStyleFunction<V>) => string | ReturnType<typeof css>;
export declare type ThemedMapFunction<V extends ValueConstraint> = (valueOrValues: ValueOrValueMap<ThemedBreakpointName, V>, mapValueToStyle: ValueToStyleFunction<V>) => <P extends object>({ theme }: StyledProps<P>) => string | ReturnType<typeof css>;
export {};
